summaryrefslogtreecommitdiffstats
path: root/qmake/generators/win32/msvc_nmake.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qmake/generators/win32/msvc_nmake.cpp')
-rw-r--r--qmake/generators/win32/msvc_nmake.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/qmake/generators/win32/msvc_nmake.cpp b/qmake/generators/win32/msvc_nmake.cpp
index d82977f0b..e8b0cde59 100644
--- a/qmake/generators/win32/msvc_nmake.cpp
+++ b/qmake/generators/win32/msvc_nmake.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -60,7 +60,7 @@ NmakeMakefileGenerator::writeMakefile(TQTextStream &t)
t << *it << " ";
}
t << "all clean:" << "\n\t"
- << "@echo \"Some of the retquired modules ("
+ << "@echo \"Some of the required modules ("
<< var("QMAKE_FAILED_RETQUIREMENTS") << ") are not available.\"" << "\n\t"
<< "@echo \"Skipped.\"" << endl << endl;
writeMakeQmake(t);
@@ -744,7 +744,7 @@ NmakeMakefileGenerator::init()
// Created files
precompObj = var("OBJECTS_DIR") + project->first("TARGET") + "_pch" + Option::obj_ext;
precompPch = var("OBJECTS_DIR") + project->first("TARGET") + "_pch.pch";
// Add linking of precompObj (retquired for whole precompiled classes)
project->variables()["OBJECTS"] += precompObj;
// Add pch file to cleanup
project->variables()["QMAKE_CLEAN"] += precompPch;
@@ -744,7 +744,7 @@ NmakeMakefileGenerator::init()
precompObj = var("OBJECTS_DIR") + project->first("TARGET") + "_pch" + Option::obj_ext;
precompPch = var("OBJECTS_DIR") + project->first("TARGET") + "_pch.pch";
- // Add linking of precompObj (retquired for whole precompiled classes)
+ // Add linking of precompObj (required for whole precompiled classes)
project->variables()["OBJECTS"] += precompObj;
// Add pch file to cleanup